@@ -7,12 +7,14 @@ mod parser;
 
 fn main() -> anyhow::Result<()> {
     let matches = clap_app!(cxx2flow =>
-        (version: "0.1.0")
+        (version: "0.1.3")
         (author: "mgt. <mgt@oi-wiki.org>")
-        (about: "Convert your C/C++ code to control flow graph")
+        (about: "Convert your C/C++ code to control flow chart")
         (@arg OUTPUT: -o --output +takes_value "Sets the output file.
 If not specified, result will be directed to stdout.
 e.g. graph.dot")
+        (@arg curved: -c --curved "Sets the style of the flow chart.
+If specified, output flow chart will have curved connection line.")
         (@arg INPUT: +required "Sets the input file. e.g. test.cpp")
         (@arg FUNCTION: "The function you want to convert. e.g. main")
     )
@@ -25,9 +27,10 @@ EXAMPLES:
     let path = matches.value_of("INPUT").unwrap();
     let func = matches.value_of("FUNCTION").map(|x| x.to_string());
     let output = matches.value_of("OUTPUT");
+    let curved = matches.is_present("curved");
     let ast_vec = parser::parse(path, func)?;
     let graph = graph::from_ast(ast_vec)?;
-    let dot = dot::from_graph(&graph)?;
+    let dot = dot::from_graph(&graph, curved)?;
     if let Some(output) = output {
         std::fs::write(output, dot)?;
     } else {
